import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:image_picker/image_picker.dart';
import 'package:provider/provider.dart';
import 'package:tencent_im_sdk_plugin/models/v2_tim_message.dart';
import 'package:tencent_im_sdk_plugin/models/v2_tim_value_callback.dart';
import 'package:tencent_im_sdk_plugin/tencent_im_sdk_plugin.dart';
import 'package:tencent_im_sdk_plugin_example/common/hexToColor.dart';
import 'package:tencent_im_sdk_plugin_example/pages/conversion/component/advanceMsgItem.dart';
import 'package:tencent_im_sdk_plugin_example/pages/conversion/dataInterface/advanceMsgList.dart';
import 'package:tencent_im_sdk_plugin_example/provider/currentMessageList.dart';

class AdvanceMsg extends StatelessWidget {
  AdvanceMsg(this.toUser, this.type);
  final String toUser;
  final int type;
  final picker = ImagePicker();
  sendImageMsg(context, type) async {
    final image = await picker.getImage(
        source: type == 0 ? ImageSource.camera : ImageSource.gallery);
    if (image == null) {
      return;
    }
    String path = image.path;

    V2TimValueCallback<V2TimMessage> res = await tencent_im_sdk_plugin
        .v2TIMManager
        .getMessageManager()
        .sendImageMessage(
          imagePath: path,
          receiver: toUser,
        );
    print("发送成功");
    if (res.code == 0) {
      String key = (type == 1 ? "c2c_${toUser}" : "group_${toUser}");
      List<V2TimMessage> list = new List();
      V2TimMessage msg = res.data;
      print(msg.toJson());
      list.add(msg);

      Provider.of<CurrentMessageListModel>(context, listen: false)
          .addMessage(key, list);
    }
  }

  Future<int> openPanel(context) {
    close() {
      Navigator.of(context).pop();
    }

    return showModalBottomSheet<int>(
      context: context,
      builder: (BuildContext ctx) {
        return Container(
          height: 260,
          color: hexToColor('ededed'),
          padding: EdgeInsets.fromLTRB(24, 16, 24, 16),
          child: GridView(
            gridDelegate: SliverGridDelegateWithFixedCrossAxisCount(
              crossAxisCount: 4,
              childAspectRatio: 1,
              mainAxisSpacing: 20,
              crossAxisSpacing: 10,
            ),
            children: [
              new AdvanceMsgList(
                name: '相册',
                icon: Icon(
                  Icons.insert_photo,
                  size: 30,
                ),
                onPressed: () async {
                  close();
                  sendImageMsg(context, 1);
                },
              ),
              new AdvanceMsgList(
                name: '拍摄',
                icon: Icon(
                  Icons.camera_alt,
                  size: 30,
                ),
                onPressed: () {
                  close();
                  sendImageMsg(context, 0);
                },
              ),
              new AdvanceMsgList(
                name: '视频',
                icon: Icon(
                  Icons.video_call,
                  size: 30,
                ),
                onPressed: () {
                  print("3");
                },
              ),
              new AdvanceMsgList(
                name: '文件',
                icon: Icon(
                  Icons.insert_drive_file,
                  size: 30,
                ),
                onPressed: () {
                  print("4");
                },
              ),
              new AdvanceMsgList(
                name: '自定义',
                icon: Icon(Icons.topic),
                onPressed: () {
                  print("5");
                },
              ),
            ].map((e) => AdvanceMsgItem(e)).toList(),
          ),
        );
      },
    );
  }

  Widget build(BuildContext context) {
    return Container(
      width: 56,
      height: 56,
      child: IconButton(
        icon: Icon(
          Icons.add,
          size: 28,
          color: Colors.black,
        ),
        onPressed: () async {
          await openPanel(context);
        },
      ),
    );
  }
}
