import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:tencent_im_sdk_plugin/models/v2_tim_message.dart';
import 'package:tencent_im_sdk_plugin/tencent_im_sdk_plugin.dart';
import 'package:tencent_im_sdk_plugin_example/common/colors.dart';
import 'package:tencent_im_sdk_plugin_example/pages/conversationInfo/conversationInfo.dart';
import 'package:tencent_im_sdk_plugin_example/pages/conversion/component/msgInput.dart';
import 'package:tencent_im_sdk_plugin_example/pages/conversion/component/sendMsg.dart';
import 'package:tencent_im_sdk_plugin/models/v2_tim_value_callback.dart';
import 'package:tencent_im_sdk_plugin/models/v2_tim_conversation.dart';
import 'package:tencent_im_sdk_plugin_example/pages/userProfile/userProfile.dart';
import 'package:tencent_im_sdk_plugin_example/provider/currentMessageList.dart';

class Conversion extends StatefulWidget {
  Conversion(this.conversationID);
  final String conversationID;
  @override
  State<StatefulWidget> createState() => ConversionState(conversationID);
}

class ConversionState extends State<Conversion> {
  String conversationID;
  int type = 1;
  String lastMessageId = '';
  String userID = '';
  String groupID = '';
  List<V2TimMessage> msgList = [];
  ScrollController scrollController = new ScrollController();
  Icon righTopIcon;
  ConversionState(conversationID) {
    this.conversationID = conversationID;
    getConversion();
  }
  void initState() {
    super.initState();
    righTopIcon = (type == 1)
        ? Icon(
            Icons.supervisor_account,
            color: CommonColors.getWitheColor(),
          )
        : Icon(
            Icons.account_box,
            color: CommonColors.getWitheColor(),
          );
  }

  openProfile(context) {
    String id = type == 1 ? userID : groupID;
    Navigator.push(
      context,
      new MaterialPageRoute(
        builder: (context) =>
            type == 1 ? UserProfile(id) : ConversationInfo(id, type),
      ),
    );
  }

  getConversion() async {
    V2TimValueCallback<V2TimConversation> data = await tencent_im_sdk_plugin
        .v2TIMManager
        .getConversationManager()
        .getConversation(conversationID: conversationID);
    String _msgID;
    int _type;
    String _groupID;
    String _userID;

    if (data.code == 0) {
      _msgID = data.data.lastMessage.msgID;
      _type = data.data.type;
      _groupID = data.data.groupID;
      _userID = data.data.userID;
      print(_type);
      print('_userID${_userID}');
      print('_groupID${_groupID}');
      setState(() {
        type = _type;
        lastMessageId = _msgID;
        groupID = _groupID;
        userID = _userID;
      });
    }
    //判断会话类型，c2c or group
    V2TimValueCallback<List<V2TimMessage>> listRes;
    if (_type == 1) {
      // c2c
      listRes = await tencent_im_sdk_plugin.v2TIMManager
          .getMessageManager()
          .getC2CHistoryMessageList(
            userID: _userID,
            count: 100,
          );
    } else if (_type == 2) {
      // group
      listRes = await tencent_im_sdk_plugin.v2TIMManager
          .getMessageManager()
          .getGroupHistoryMessageList(
            groupID: _groupID,
            count: 100,
          );
    }
    if (listRes.code == 0) {
      List<V2TimMessage> list = listRes.data;
      if (list == null || list.length == 0) {
        print('没有消息啊！！！');
        list = new List();
      }

      Provider.of<CurrentMessageListModel>(context, listen: false)
          .addMessage(conversationID, list);
    } else {
      print('获取历史消息失败');
    }
  }

  // @override
  // void didChangeDependencies() {
  //   super.didChangeDependencies();

  //   print('MyHomePage==didChangeDependencies');
  // }
  isreverse() {
    bool isr = false;
    try {
      if (scrollController.position.maxScrollExtent > 0) {
        isr = true;
      }
    } catch (err) {}
    return isr;
  }

  @override
  Widget build(BuildContext context) {
    Map<String, List<V2TimMessage>> currentMessageMap =
        Provider.of<CurrentMessageListModel>(context).messageMap;
    List<V2TimMessage> currentMessageList = new List();

    if (groupID != null && groupID != '') {
      print("设置群组会话已读");
      tencent_im_sdk_plugin.v2TIMManager
          .getMessageManager()
          .markGroupMessageAsRead(groupID: groupID);
    }
    if (userID != null && userID != '') {
      print("设置个人会话已读");
      tencent_im_sdk_plugin.v2TIMManager
          .getMessageManager()
          .markC2CMessageAsRead(userID: userID);
    }
    if (currentMessageMap != null) {
      currentMessageList = currentMessageMap[conversationID];
    }

    return Scaffold(
      appBar: AppBar(
        title: Text("会话"),
        backgroundColor: CommonColors.getThemeColor(),
        actions: [
          IconButton(
            icon: righTopIcon,
            onPressed: () {
              openProfile(context);
            },
          )
        ],
      ),
      body: Column(
        children: [
          Expanded(
            child: Container(
              color: Colors.white,
              child: SingleChildScrollView(
                controller: scrollController,
                reverse: isreverse(), //注意设置为反向
                padding: EdgeInsets.fromLTRB(12, 0, 12, 0),
                child: Column(
                  children: (currentMessageList == null ||
                          currentMessageList.length == 0)
                      ? [Container()]
                      : currentMessageList
                          .map(
                            (e) => SendMsg(e),
                          )
                          .toList(),
                ),
              ),
            ),
          ),
          type == 0 ? Container() : MsgInput(type == 1 ? userID : groupID, type)
        ],
      ),
    );
  }
}
