import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:tencent_im_sdk_plugin/models/v2_tim_callback.dart';
import 'package:tencent_im_sdk_plugin/models/v2_tim_friend_application.dart';
import 'package:tencent_im_sdk_plugin/models/v2_tim_friend_operation_result.dart';
import 'package:tencent_im_sdk_plugin/models/v2_tim_group_application.dart';
import 'package:tencent_im_sdk_plugin/models/v2_tim_value_callback.dart';
import 'package:tencent_im_sdk_plugin/tencent_im_sdk_plugin.dart';
import 'package:tencent_im_sdk_plugin_example/common/avatar.dart';
import 'package:tencent_im_sdk_plugin_example/common/colors.dart';
import 'package:tencent_im_sdk_plugin_example/provider/friendApplication.dart';
import 'package:tencent_im_sdk_plugin_example/provider/groupApplication.dart';
import 'package:toast/toast.dart';

class NewFriendOrGroupNotice extends StatefulWidget {
  final int type;
  NewFriendOrGroupNotice(this.type);
  @override
  State<StatefulWidget> createState() => NewFriendOrGroupNoticeState();
}

class ApplicationItem extends StatelessWidget {
  ApplicationItem(this.application);
  final V2TimFriendApplication application;
  refuse(context) async {
    V2TimValueCallback<V2TimFriendOperationResult> res =
        await tencent_im_sdk_plugin
            .v2TIMManager
            .getFriendshipManager()
            .refuseFriendApplication(
                type: application.type, userID: application.userID);
    if (res.code == 0) {
      Toast.show("拒绝成功", context);
      Provider.of<FriendApplicationModel>(context, listen: false)
          .removeApplicationByuserId(application.userID);
    } else {
      print(res.desc);
    }
  }

  accept(context) async {
    V2TimValueCallback<V2TimFriendOperationResult> res =
        await tencent_im_sdk_plugin.v2TIMManager
            .getFriendshipManager()
            .acceptFriendApplication(
              type: application.type,
              userID: application.userID,
              responseType: 1, //加双向好友
            );
    if (res.code == 0) {
      if (res.code == 0) {
        Toast.show("添加成功", context);
        Provider.of<FriendApplicationModel>(context, listen: false)
            .removeApplicationByuserId(application.userID);
      } else {
        print(res.desc);
      }
    } else {
      print(res.desc);
    }
  }

  @override
  Widget build(BuildContext context) {
    print("当前申请${application.toJson()}");
    return Material(
      child: Ink(
        color: CommonColors.getWitheColor(),
        child: InkWell(
          onTap: () {},
          child: Container(
            padding: EdgeInsets.only(left: 10, right: 10),
            height: 50,
            child: Row(
              children: [
                Avatar(
                  width: 30,
                  height: 30,
                  radius: 2,
                  avtarUrl:
                      application.faceUrl == '' || application.faceUrl == null
                          ? 'images/logo.png'
                          : application.faceUrl,
                ),
                Container(
                  child: Text("${application.userID}申请加您为好友"),
                  padding: EdgeInsets.only(left: 10),
                ),
                Expanded(
                  child: Row(
                    mainAxisAlignment: MainAxisAlignment.end,
                    children: [
                      InkWell(
                        child: Container(
                          padding: EdgeInsets.only(left: 5, right: 5),
                          child: Text(
                            "同意",
                            style: TextStyle(
                              color: CommonColors.getThemeColor(),
                            ),
                          ),
                        ),
                        onTap: () {
                          accept(context);
                        },
                      ),
                      InkWell(
                        child: Container(
                          padding: EdgeInsets.only(left: 5, right: 5),
                          child: Text(
                            "拒绝",
                            style: TextStyle(
                              color: CommonColors.getTextWeakColor(),
                            ),
                          ),
                        ),
                        onTap: () {
                          refuse(context);
                        },
                      )
                    ],
                  ),
                )
              ],
            ),
          ),
        ),
      ),
    );
  }
}

class GroupApplicationItem extends StatelessWidget {
  GroupApplicationItem(this.application);
  final V2TimGroupApplication application;
  refuse(context) async {
    // V2TimValueCallback<V2TimFriendOperationResult> res =
    //     await tencent_im_sdk_plugin
    //         .v2TIMManager
    //         .getFriendshipManager()
    //         .refuseFriendApplication(
    //             type: application.type, userID: application.groupID);
    // if (res.code == 0) {
    //   Toast.show("拒绝成功", context);
    //   Provider.of<FriendApplicationModel>(context, listen: false)
    //       .removeApplicationByuserId(application.userID);
    // } else {
    //   print(res.desc);
    // }
  }

  accept(context) async {
    V2TimCallback res = await tencent_im_sdk_plugin.v2TIMManager
        .getGroupManager()
        .acceptGroupApplication(
          groupID: application.groupID,
          toUser: application.toUser,
          fromUser: application.fromUser,
          addTime: application.addTime,
          type: application.type,
        );
    print("同意加群${res.code}");
  }

  @override
  Widget build(Object context) {
    return Material(
      child: Ink(
        color: CommonColors.getWitheColor(),
        child: InkWell(
          onTap: () {},
          child: Container(
            padding: EdgeInsets.only(left: 10, right: 10),
            height: 50,
            child: Row(
              children: [
                Avatar(
                  width: 30,
                  height: 30,
                  radius: 2,
                  avtarUrl: application.fromUserFaceUrl == '' ||
                          application.fromUserFaceUrl == null
                      ? 'images/logo.png'
                      : application.fromUserFaceUrl,
                ),
                Container(
                  child:
                      Text("${application.fromUser}申请加入${application.groupID}"),
                  padding: EdgeInsets.only(left: 10),
                ),
                Expanded(
                  child: Row(
                    mainAxisAlignment: MainAxisAlignment.end,
                    children: [
                      InkWell(
                        child: Container(
                          padding: EdgeInsets.only(left: 5, right: 5),
                          child: Text(
                            "同意",
                            style: TextStyle(
                              color: CommonColors.getThemeColor(),
                            ),
                          ),
                        ),
                        onTap: () {
                          accept(context);
                        },
                      ),
                      InkWell(
                        child: Container(
                          padding: EdgeInsets.only(left: 5, right: 5),
                          child: Text(
                            "拒绝",
                            style: TextStyle(
                              color: CommonColors.getTextWeakColor(),
                            ),
                          ),
                        ),
                        onTap: () {
                          refuse(context);
                        },
                      )
                    ],
                  ),
                )
              ],
            ),
          ),
        ),
      ),
    );
  }
}

class NewFriendOrGroupNoticeState extends State<NewFriendOrGroupNotice> {
  int type;
  void initState() {
    this.type = widget.type;
    super.initState();
  }

  @override
  Widget build(Object context) {
    List<V2TimFriendApplication> applicationList =
        Provider.of<FriendApplicationModel>(context).friendApplicationList;
    List<V2TimGroupApplication> groupApplicationList =
        Provider.of<GroupApplicationModel>(context).groupApplicationList;
    return Scaffold(
      appBar: AppBar(
        title: type == 1 ? Text('新的好友申请') : Text('新的加群申请'),
        backgroundColor: CommonColors.getThemeColor(),
      ),
      body: Column(
        children: [
          Expanded(
            child: Container(
              color: CommonColors.getGapColor(),
              child: type == 1
                  ? applicationList.length > 0
                      ? ListView(
                          children: applicationList
                              .map((e) => ApplicationItem(e))
                              .toList(),
                        )
                      : Center(
                          child: Text(
                            '暂无新的申请',
                            style: TextStyle(
                                color: CommonColors.getTextWeakColor()),
                          ),
                        )
                  : groupApplicationList.length > 0
                      ? ListView(
                          children: groupApplicationList
                              .map((e) => GroupApplicationItem(e))
                              .toList(),
                        )
                      : Center(
                          child: Text(
                            '暂无新的申请',
                            style: TextStyle(
                                color: CommonColors.getTextWeakColor()),
                          ),
                        ),
            ),
          )
        ],
      ),
    );
  }
}
