import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:tencent_im_sdk_plugin/models/v2_tim_message.dart';

class CurrentMessageListModel with ChangeNotifier, DiagnosticableTreeMixin {
  Map<String, List<V2TimMessage>> _messageMap = new Map();
  List<V2TimMessage> _msgList = new List();
  get msgList => _msgList;
  get messageMap => _messageMap;
  setCurrentMessageList(newMsgList) {
    _msgList = newMsgList;
    notifyListeners();
    return _msgList;
  }

  clear() {
    _msgList = new List();
    _messageMap = new Map();
    notifyListeners();
  }

  addMessage(String key, List<V2TimMessage> value) {
    if (_messageMap.containsKey(key)) {
      _messageMap[key].addAll(value);
    } else {
      List<V2TimMessage> messageList = new List();
      messageList.addAll(value);
      _messageMap[key] = messageList;
    }
    //去重
    Map<String, V2TimMessage> rebuildMap = new Map();
    _messageMap[key].forEach((element) {
      rebuildMap[element.msgID] = element;
    });
    _messageMap[key] = rebuildMap.values.toList();
    rebuildMap.clear();
    _messageMap[key]
        .sort((left, right) => left.timestamp.compareTo(right.timestamp));

    notifyListeners();
    return _messageMap;
  }

  deleteMessage(String key) {
    _messageMap.remove(key);
    notifyListeners();
  }

  void debugFillProperties(DiagnosticPropertiesBuilder properties) {
    super.debugFillProperties(properties);
    properties.add(IntProperty('msgList', msgList));
    properties.add(IntProperty('messageMap', messageMap));
  }
}
